#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class crossover_tolerance(Real):
    """
    Set the fraction a particle is moved towards the cell center (0: not moved, 1: moved to cell center).
    """

    fluent_name = "crossover-tolerance"

