#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class sbes_update_interval_k_omega(Integer):
    """
    Set an integer value how often the k and omega equations are updated in a transient SBES run.
    """

    fluent_name = "sbes-update-interval-k-omega"

