#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class interpolate_flow_viscosity(Boolean):
    """
    Enable/disable interpolation of flow laminar viscosity to the particle position.
    """

    fluent_name = "interpolate-flow-viscosity?"

