#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .law_1 import law_1
from .law_2 import law_2
from .law_3 import law_3
from .law_4 import law_4
from .law_5 import law_5
from .law_6 import law_6
from .law_7 import law_7
from .law_8 import law_8
from .law_9 import law_9
from .law_10 import law_10
from .switch import switch
class custom_laws(Group):
    """
    'custom_laws' child.
    """

    fluent_name = "custom-laws"

    child_names = \
        ['law_1', 'law_2', 'law_3', 'law_4', 'law_5', 'law_6', 'law_7',
         'law_8', 'law_9', 'law_10', 'switch']

    law_1: law_1 = law_1
    """
    law_1 child of custom_laws.
    """
    law_2: law_2 = law_2
    """
    law_2 child of custom_laws.
    """
    law_3: law_3 = law_3
    """
    law_3 child of custom_laws.
    """
    law_4: law_4 = law_4
    """
    law_4 child of custom_laws.
    """
    law_5: law_5 = law_5
    """
    law_5 child of custom_laws.
    """
    law_6: law_6 = law_6
    """
    law_6 child of custom_laws.
    """
    law_7: law_7 = law_7
    """
    law_7 child of custom_laws.
    """
    law_8: law_8 = law_8
    """
    law_8 child of custom_laws.
    """
    law_9: law_9 = law_9
    """
    law_9 child of custom_laws.
    """
    law_10: law_10 = law_10
    """
    law_10 child of custom_laws.
    """
    switch: switch = switch
    """
    switch child of custom_laws.
    """
