#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_24 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .d import d
from .q_dot import q_dot
from .material import material
from .thermal_bc import thermal_bc
from .t import t
from .q import q
from .h import h
from .tinf_1 import tinf
from .planar_conduction import planar_conduction
from .shell_conduction import shell_conduction
from .thin_wall import thin_wall
from .motion_bc import motion_bc
from .shear_bc import shear_bc
from .rough_bc import rough_bc
from .moving import moving
from .relative import relative
from .rotating import rotating
from .vmag import vmag
from .wall_translation import wall_translation
from .components_1 import components
from .velocity_1 import velocity
from .in_emiss import in_emiss
from .ex_emiss import ex_emiss
from .trad import trad
from .int_rad import int_rad
from .trad_internal import trad_internal
from .area_enhancement_factor import area_enhancement_factor
from .rough_option import rough_option
from .rough_nasa import rough_nasa
from .rough_shin_et_al import rough_shin_et_al
from .rough_data import rough_data
from .roughness_height import roughness_height
from .roughness_const import roughness_const
from .roughness_height_cp import roughness_height_cp
from .roughness_const_cp import roughness_const_cp
from .roughness_const_nasa import roughness_const_nasa
from .roughness_const_shin import roughness_const_shin
from .roughness_const_data import roughness_const_data
from .variable_roughness import variable_roughness
from .free_stream_velocity import free_stream_velocity
from .free_stream_temp import free_stream_temp
from .characteristic_length import characteristic_length
from .free_stream_temp_cp import free_stream_temp_cp
from .characteristic_length_cp import characteristic_length_cp
from .liquid_content import liquid_content
from .liquid_content_cp import liquid_content_cp
from .droplet_diameter import droplet_diameter
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_norm_coeff import dpm_bc_norm_coeff
from .dpm_bc_tang_coeff import dpm_bc_tang_coeff
from .dpm_bc_frictn_coeff import dpm_bc_frictn_coeff
from .dpm_bc_udf import dpm_bc_udf
from .dpm_film_splash_nsamp import dpm_film_splash_nsamp
from .dpm_crit_temp_option import dpm_crit_temp_option
from .dpm_critical_temp_factor import dpm_critical_temp_factor
from .dpm_calibratable_temp import dpm_calibratable_temp
from .dpm_impingement_splashing_model import dpm_impingement_splashing_model
from .dpm_upper_deposition_limit_offset import dpm_upper_deposition_limit_offset
from .dpm_deposition_delta_t import dpm_deposition_delta_t
from .dpm_laplace_number_constant import dpm_laplace_number_constant
from .dpm_partial_evaporation_ratio import dpm_partial_evaporation_ratio
from .ra_roughness import ra_roughness
from .rz_roughness import rz_roughness
from .rq_roughness import rq_roughness
from .rsm_roughness import rsm_roughness
from .dpm_bc_erosion_generic import dpm_bc_erosion_generic
from .dpm_bc_erosion import dpm_bc_erosion
from .dpm_bc_erosion_c import dpm_bc_erosion_c
from .dpm_bc_erosion_n import dpm_bc_erosion_n
from .dpm_bc_erosion_finnie import dpm_bc_erosion_finnie
from .dpm_bc_erosion_finnie_k import dpm_bc_erosion_finnie_k
from .dpm_bc_erosion_finnie_vel_exp import dpm_bc_erosion_finnie_vel_exp
from .dpm_bc_erosion_finnie_max_erosion_angle import dpm_bc_erosion_finnie_max_erosion_angle
from .dpm_bc_erosion_mclaury import dpm_bc_erosion_mclaury
from .dpm_bc_erosion_mclaury_a import dpm_bc_erosion_mclaury_a
from .dpm_bc_erosion_mclaury_vel_exp import dpm_bc_erosion_mclaury_vel_exp
from .dpm_bc_erosion_mclaury_transition_angle import dpm_bc_erosion_mclaury_transition_angle
from .dpm_bc_erosion_mclaury_b import dpm_bc_erosion_mclaury_b
from .dpm_bc_erosion_mclaury_c import dpm_bc_erosion_mclaury_c
from .dpm_bc_erosion_mclaury_w import dpm_bc_erosion_mclaury_w
from .dpm_bc_erosion_mclaury_x import dpm_bc_erosion_mclaury_x
from .dpm_bc_erosion_mclaury_y import dpm_bc_erosion_mclaury_y
from .dpm_bc_erosion_oka import dpm_bc_erosion_oka
from .dpm_bc_erosion_oka_e90 import dpm_bc_erosion_oka_e90
from .dpm_bc_erosion_oka_hv import dpm_bc_erosion_oka_hv
from .dpm_bc_erosion_oka_n1 import dpm_bc_erosion_oka_n1
from .dpm_bc_erosion_oka_n2 import dpm_bc_erosion_oka_n2
from .dpm_bc_erosion_oka_k2 import dpm_bc_erosion_oka_k2
from .dpm_bc_erosion_oka_k3 import dpm_bc_erosion_oka_k3
from .dpm_bc_erosion_oka_dref import dpm_bc_erosion_oka_dref
from .dpm_bc_erosion_oka_vref import dpm_bc_erosion_oka_vref
from .dpm_bc_erosion_dnv import dpm_bc_erosion_dnv
from .dpm_bc_erosion_dnv_k import dpm_bc_erosion_dnv_k
from .dpm_bc_erosion_dnv_n import dpm_bc_erosion_dnv_n
from .dpm_bc_erosion_dnv_ductile import dpm_bc_erosion_dnv_ductile
from .dpm_bc_erosion_shear import dpm_bc_erosion_shear
from .dpm_bc_erosion_shear_v import dpm_bc_erosion_shear_v
from .dpm_bc_erosion_shear_c import dpm_bc_erosion_shear_c
from .dpm_bc_erosion_shear_packing_limit import dpm_bc_erosion_shear_packing_limit
from .dpm_bc_erosion_shielding import dpm_bc_erosion_shielding
from .dpm_wall_heat_exchange import dpm_wall_heat_exchange
from .dpm_film_condensation import dpm_film_condensation
from .dpm_film_bl_model import dpm_film_bl_model
from .dpm_particle_stripping import dpm_particle_stripping
from .dpm_critical_shear_stress import dpm_critical_shear_stress
from .dpm_film_separation_model import dpm_film_separation_model
from .dpm_critical_we_number import dpm_critical_we_number
from .dpm_film_separation_angle import dpm_film_separation_angle
from .dpm_allow_lwf_to_vof import dpm_allow_lwf_to_vof
from .dpm_allow_vof_to_lwf import dpm_allow_vof_to_lwf
from .dpm_initialize_lwf import dpm_initialize_lwf
from .dpm_initial_height import dpm_initial_height
from .film_velocity import film_velocity
from .dpm_initial_temperature import dpm_initial_temperature
from .dpm_initial_injection import dpm_initial_injection
from .film_parcel_surface_area_density import film_parcel_surface_area_density
from .minimum_number_of_parcels_per_face import minimum_number_of_parcels_per_face
from .band_in_emiss import band_in_emiss
from .radiation_bc import radiation_bc
from .mc_bsource_p import mc_bsource_p
from .mc_poldfun_p import mc_poldfun_p
from .polar_func_type import polar_func_type
from .mc_polar_expr import mc_polar_expr
from .polar_pair_list import polar_pair_list
from .pold_pair_list_rad import pold_pair_list_rad
from .radiation_direction import radiation_direction
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .band_diffuse_frac import band_diffuse_frac
from .radiating_s2s_surface import radiating_s2s_surface
from .critical_zone import critical_zone
from .fpsc import fpsc
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_fluxes import solar_fluxes
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .v_transmissivity import v_transmissivity
from .ir_transmissivity import ir_transmissivity
from .v_opq_absorbtivity import v_opq_absorbtivity
from .ir_opq_absorbtivity import ir_opq_absorbtivity
from .v_st_absorbtivity import v_st_absorbtivity
from .ir_st_absorbtivity import ir_st_absorbtivity
from .d_st_absorbtivity import d_st_absorbtivity
from .d_transmissivity import d_transmissivity
from .fsi_interface import fsi_interface
from .react import react
from .partially_catalytic import partially_catalytic
from .partially_catalytic_material import partially_catalytic_material
from .partially_catalytic_recombination_coefficient_o import partially_catalytic_recombination_coefficient_o
from .partially_catalytic_recombination_coefficient_n import partially_catalytic_recombination_coefficient_n
from .partially_catalytic_recombination_model import partially_catalytic_recombination_model
from .species_spec import species_spec
from .mf import mf
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .elec_potential_jump import elec_potential_jump
from .elec_potential_resistance import elec_potential_resistance
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .echem_reaction import echem_reaction
from .elec_potential_mechs import elec_potential_mechs
from .faradaic_heat import faradaic_heat
from .li_ion_type import li_ion_type
from .li_ion_value import li_ion_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .per_dispx import per_dispx
from .per_dispy import per_dispy
from .per_dispz import per_dispz
from .per_imagx import per_imagx
from .per_imagy import per_imagy
from .per_imagz import per_imagz
from .freq import freq
from .amp import amp
from .nodal_diam import nodal_diam
from .pass_number import pass_number
from .fwd import fwd
from .aero import aero
from .cmplx import cmplx
from .norm import norm
from .method_2 import method
from .uds_bc import uds_bc
from .uds import uds
from .gtemp_bc import gtemp_bc
from .g_temperature import g_temperature
from .g_qflux import g_qflux
from .wall_restitution_coeff import wall_restitution_coeff
from .omega import omega
from .rotation_axis_origin import rotation_axis_origin
from .rotation_axis_direction import rotation_axis_direction
from .adhesion_angle import adhesion_angle
from .specified_shear import specified_shear
from .shear_stress import shear_stress
from .fslip import fslip
from .eslip import eslip
from .surf_tens_grad import surf_tens_grad
from .contact_resistance import contact_resistance
from .reaction_mechs_1 import reaction_mechs
from .surf_washcoat_factor import surf_washcoat_factor
from .initial_deposition_height import initial_deposition_height
from .solid_species_density import solid_species_density
from .ablation_select_model import ablation_select_model
from .ablation_vielle_a import ablation_vielle_a
from .ablation_vielle_n import ablation_vielle_n
from .ablation_flux import ablation_flux
from .ablation_surfacerxn_density import ablation_surfacerxn_density
from .ablation_species_mf import ablation_species_mf
from .specular_coeff import specular_coeff
from .mom_accom_coef import mom_accom_coef
from .therm_accom_coef import therm_accom_coef
from .eve_accom_coef import eve_accom_coef
from .film_wall import film_wall
from .film_wall_bc import film_wall_bc
from .film_height import film_height
from .flux_momentum import flux_momentum
from .film_relative_vel import film_relative_vel
from .film_bc_imp_press import film_bc_imp_press
from .film_temperature import film_temperature
from .film_scalar import film_scalar
from .film_source import film_source
from .film_h_src import film_h_src
from .momentum_source import momentum_source
from .film_t_src import film_t_src
from .film_s_src import film_s_src
from .film_phase_change import film_phase_change
from .film_phase_change_model import film_phase_change_model
from .film_cond_const import film_cond_const
from .film_vapo_const import film_vapo_const
from .film_cond_rate import film_cond_rate
from .film_vapo_rate import film_vapo_rate
from .film_momentum_coupling import film_momentum_coupling
from .film_splash_wall import film_splash_wall
from .film_boundary_separation import film_boundary_separation
from .film_impinge_model import film_impinge_model
from .film_splash_nparc import film_splash_nparc
from .film_crit_temp_factor import film_crit_temp_factor
from .film_roughness_ra import film_roughness_ra
from .film_roughness_rz import film_roughness_rz
from .film_upper_deposition_limit_offset import film_upper_deposition_limit_offset
from .film_deposition_delta_t import film_deposition_delta_t
from .film_laplace_number_constant import film_laplace_number_constant
from .film_partial_evap_ratio import film_partial_evap_ratio
from .film_contact_angle import film_contact_angle
from .film_contact_angle_mean import film_contact_angle_mean
from .film_contact_angle_rstd import film_contact_angle_rstd
from .film_contact_angle_beta import film_contact_angle_beta
from .film_vof_coupling_high import film_vof_coupling_high
from .film_vof_trans_high import film_vof_trans_high
from .film_vof_trans_high_relax import film_vof_trans_high_relax
from .film_vof_coupling_low import film_vof_coupling_low
from .film_vof_trans_low import film_vof_trans_low
from .film_vof_trans_low_relax import film_vof_trans_low_relax
from .caf import caf
from .thermal_stabilization import thermal_stabilization
from .scale_factor import scale_factor
from .stab_method import stab_method
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype
from .fensapice_ice_icing_mode import fensapice_ice_icing_mode
from .fensapice_ice_hflux import fensapice_ice_hflux
from .fensapice_ice_hflux_1 import fensapice_ice_hflux_1
from .fensapice_drop_vwet import fensapice_drop_vwet
class wall_child(Group):
    """
    'child_object_type' of wall.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'd', 'q_dot',
         'material', 'thermal_bc', 't', 'q', 'h', 'tinf', 'planar_conduction',
         'shell_conduction', 'thin_wall', 'motion_bc', 'shear_bc', 'rough_bc',
         'moving', 'relative', 'rotating', 'vmag', 'wall_translation',
         'components', 'velocity', 'in_emiss', 'ex_emiss', 'trad', 'int_rad',
         'trad_internal', 'area_enhancement_factor', 'rough_option',
         'rough_nasa', 'rough_shin_et_al', 'rough_data', 'roughness_height',
         'roughness_const', 'roughness_height_cp', 'roughness_const_cp',
         'roughness_const_nasa', 'roughness_const_shin',
         'roughness_const_data', 'variable_roughness', 'free_stream_velocity',
         'free_stream_temp', 'characteristic_length', 'free_stream_temp_cp',
         'characteristic_length_cp', 'liquid_content', 'liquid_content_cp',
         'droplet_diameter', 'dpm_bc_type', 'dpm_bc_collision_partner',
         'reinj_inj', 'dpm_bc_norm_coeff', 'dpm_bc_tang_coeff',
         'dpm_bc_frictn_coeff', 'dpm_bc_udf', 'dpm_film_splash_nsamp',
         'dpm_crit_temp_option', 'dpm_critical_temp_factor',
         'dpm_calibratable_temp', 'dpm_impingement_splashing_model',
         'dpm_upper_deposition_limit_offset', 'dpm_deposition_delta_t',
         'dpm_laplace_number_constant', 'dpm_partial_evaporation_ratio',
         'ra_roughness', 'rz_roughness', 'rq_roughness', 'rsm_roughness',
         'dpm_bc_erosion_generic', 'dpm_bc_erosion', 'dpm_bc_erosion_c',
         'dpm_bc_erosion_n', 'dpm_bc_erosion_finnie',
         'dpm_bc_erosion_finnie_k', 'dpm_bc_erosion_finnie_vel_exp',
         'dpm_bc_erosion_finnie_max_erosion_angle', 'dpm_bc_erosion_mclaury',
         'dpm_bc_erosion_mclaury_a', 'dpm_bc_erosion_mclaury_vel_exp',
         'dpm_bc_erosion_mclaury_transition_angle',
         'dpm_bc_erosion_mclaury_b', 'dpm_bc_erosion_mclaury_c',
         'dpm_bc_erosion_mclaury_w', 'dpm_bc_erosion_mclaury_x',
         'dpm_bc_erosion_mclaury_y', 'dpm_bc_erosion_oka',
         'dpm_bc_erosion_oka_e90', 'dpm_bc_erosion_oka_hv',
         'dpm_bc_erosion_oka_n1', 'dpm_bc_erosion_oka_n2',
         'dpm_bc_erosion_oka_k2', 'dpm_bc_erosion_oka_k3',
         'dpm_bc_erosion_oka_dref', 'dpm_bc_erosion_oka_vref',
         'dpm_bc_erosion_dnv', 'dpm_bc_erosion_dnv_k', 'dpm_bc_erosion_dnv_n',
         'dpm_bc_erosion_dnv_ductile', 'dpm_bc_erosion_shear',
         'dpm_bc_erosion_shear_v', 'dpm_bc_erosion_shear_c',
         'dpm_bc_erosion_shear_packing_limit', 'dpm_bc_erosion_shielding',
         'dpm_wall_heat_exchange', 'dpm_film_condensation',
         'dpm_film_bl_model', 'dpm_particle_stripping',
         'dpm_critical_shear_stress', 'dpm_film_separation_model',
         'dpm_critical_we_number', 'dpm_film_separation_angle',
         'dpm_allow_lwf_to_vof', 'dpm_allow_vof_to_lwf', 'dpm_initialize_lwf',
         'dpm_initial_height', 'film_velocity', 'dpm_initial_temperature',
         'dpm_initial_injection', 'film_parcel_surface_area_density',
         'minimum_number_of_parcels_per_face', 'band_in_emiss',
         'radiation_bc', 'mc_bsource_p', 'mc_poldfun_p', 'polar_func_type',
         'mc_polar_expr', 'polar_pair_list', 'pold_pair_list_rad',
         'radiation_direction', 'coll_dtheta', 'coll_dphi', 'band_q_irrad',
         'band_q_irrad_diffuse', 'band_diffuse_frac', 'radiating_s2s_surface',
         'critical_zone', 'fpsc', 'parallel_collimated_beam', 'solar_fluxes',
         'solar_direction', 'solar_irradiation', 'v_transmissivity',
         'ir_transmissivity', 'v_opq_absorbtivity', 'ir_opq_absorbtivity',
         'v_st_absorbtivity', 'ir_st_absorbtivity', 'd_st_absorbtivity',
         'd_transmissivity', 'fsi_interface', 'react', 'partially_catalytic',
         'partially_catalytic_material',
         'partially_catalytic_recombination_coefficient_o',
         'partially_catalytic_recombination_coefficient_n',
         'partially_catalytic_recombination_model', 'species_spec', 'mf',
         'elec_potential_type', 'potential_value', 'elec_potential_jump',
         'elec_potential_resistance', 'dual_potential_type',
         'dual_potential_value', 'echem_reaction', 'elec_potential_mechs',
         'faradaic_heat', 'li_ion_type', 'li_ion_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'per_dispx', 'per_dispy', 'per_dispz',
         'per_imagx', 'per_imagy', 'per_imagz', 'freq', 'amp', 'nodal_diam',
         'pass_number', 'fwd', 'aero', 'cmplx', 'norm', 'method', 'uds_bc',
         'uds', 'gtemp_bc', 'g_temperature', 'g_qflux',
         'wall_restitution_coeff', 'omega', 'rotation_axis_origin',
         'rotation_axis_direction', 'adhesion_angle', 'specified_shear',
         'shear_stress', 'fslip', 'eslip', 'surf_tens_grad',
         'contact_resistance', 'reaction_mechs', 'surf_washcoat_factor',
         'initial_deposition_height', 'solid_species_density',
         'ablation_select_model', 'ablation_vielle_a', 'ablation_vielle_n',
         'ablation_flux', 'ablation_surfacerxn_density',
         'ablation_species_mf', 'specular_coeff', 'mom_accom_coef',
         'therm_accom_coef', 'eve_accom_coef', 'film_wall', 'film_wall_bc',
         'film_height', 'flux_momentum', 'film_relative_vel',
         'film_bc_imp_press', 'film_temperature', 'film_scalar',
         'film_source', 'film_h_src', 'momentum_source', 'film_t_src',
         'film_s_src', 'film_phase_change', 'film_phase_change_model',
         'film_cond_const', 'film_vapo_const', 'film_cond_rate',
         'film_vapo_rate', 'film_momentum_coupling', 'film_splash_wall',
         'film_boundary_separation', 'film_impinge_model',
         'film_splash_nparc', 'film_crit_temp_factor', 'film_roughness_ra',
         'film_roughness_rz', 'film_upper_deposition_limit_offset',
         'film_deposition_delta_t', 'film_laplace_number_constant',
         'film_partial_evap_ratio', 'film_contact_angle',
         'film_contact_angle_mean', 'film_contact_angle_rstd',
         'film_contact_angle_beta', 'film_vof_coupling_high',
         'film_vof_trans_high', 'film_vof_trans_high_relax',
         'film_vof_coupling_low', 'film_vof_trans_low',
         'film_vof_trans_low_relax', 'caf', 'thermal_stabilization',
         'scale_factor', 'stab_method', 'fensapice_flow_bc_subtype',
         'fensapice_ice_icing_mode', 'fensapice_ice_hflux',
         'fensapice_ice_hflux_1', 'fensapice_drop_vwet']

    phase: phase = phase
    """
    phase child of wall_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of wall_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of wall_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of wall_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of wall_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of wall_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of wall_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of wall_child.
    """
    d: d = d
    """
    d child of wall_child.
    """
    q_dot: q_dot = q_dot
    """
    q_dot child of wall_child.
    """
    material: material = material
    """
    material child of wall_child.
    """
    thermal_bc: thermal_bc = thermal_bc
    """
    thermal_bc child of wall_child.
    """
    t: t = t
    """
    t child of wall_child.
    """
    q: q = q
    """
    q child of wall_child.
    """
    h: h = h
    """
    h child of wall_child.
    """
    tinf: tinf = tinf
    """
    tinf child of wall_child.
    """
    planar_conduction: planar_conduction = planar_conduction
    """
    planar_conduction child of wall_child.
    """
    shell_conduction: shell_conduction = shell_conduction
    """
    shell_conduction child of wall_child.
    """
    thin_wall: thin_wall = thin_wall
    """
    thin_wall child of wall_child.
    """
    motion_bc: motion_bc = motion_bc
    """
    motion_bc child of wall_child.
    """
    shear_bc: shear_bc = shear_bc
    """
    shear_bc child of wall_child.
    """
    rough_bc: rough_bc = rough_bc
    """
    rough_bc child of wall_child.
    """
    moving: moving = moving
    """
    moving child of wall_child.
    """
    relative: relative = relative
    """
    relative child of wall_child.
    """
    rotating: rotating = rotating
    """
    rotating child of wall_child.
    """
    vmag: vmag = vmag
    """
    vmag child of wall_child.
    """
    wall_translation: wall_translation = wall_translation
    """
    wall_translation child of wall_child.
    """
    components: components = components
    """
    components child of wall_child.
    """
    velocity: velocity = velocity
    """
    velocity child of wall_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of wall_child.
    """
    ex_emiss: ex_emiss = ex_emiss
    """
    ex_emiss child of wall_child.
    """
    trad: trad = trad
    """
    trad child of wall_child.
    """
    int_rad: int_rad = int_rad
    """
    int_rad child of wall_child.
    """
    trad_internal: trad_internal = trad_internal
    """
    trad_internal child of wall_child.
    """
    area_enhancement_factor: area_enhancement_factor = area_enhancement_factor
    """
    area_enhancement_factor child of wall_child.
    """
    rough_option: rough_option = rough_option
    """
    rough_option child of wall_child.
    """
    rough_nasa: rough_nasa = rough_nasa
    """
    rough_nasa child of wall_child.
    """
    rough_shin_et_al: rough_shin_et_al = rough_shin_et_al
    """
    rough_shin_et_al child of wall_child.
    """
    rough_data: rough_data = rough_data
    """
    rough_data child of wall_child.
    """
    roughness_height: roughness_height = roughness_height
    """
    roughness_height child of wall_child.
    """
    roughness_const: roughness_const = roughness_const
    """
    roughness_const child of wall_child.
    """
    roughness_height_cp: roughness_height_cp = roughness_height_cp
    """
    roughness_height_cp child of wall_child.
    """
    roughness_const_cp: roughness_const_cp = roughness_const_cp
    """
    roughness_const_cp child of wall_child.
    """
    roughness_const_nasa: roughness_const_nasa = roughness_const_nasa
    """
    roughness_const_nasa child of wall_child.
    """
    roughness_const_shin: roughness_const_shin = roughness_const_shin
    """
    roughness_const_shin child of wall_child.
    """
    roughness_const_data: roughness_const_data = roughness_const_data
    """
    roughness_const_data child of wall_child.
    """
    variable_roughness: variable_roughness = variable_roughness
    """
    variable_roughness child of wall_child.
    """
    free_stream_velocity: free_stream_velocity = free_stream_velocity
    """
    free_stream_velocity child of wall_child.
    """
    free_stream_temp: free_stream_temp = free_stream_temp
    """
    free_stream_temp child of wall_child.
    """
    characteristic_length: characteristic_length = characteristic_length
    """
    characteristic_length child of wall_child.
    """
    free_stream_temp_cp: free_stream_temp_cp = free_stream_temp_cp
    """
    free_stream_temp_cp child of wall_child.
    """
    characteristic_length_cp: characteristic_length_cp = characteristic_length_cp
    """
    characteristic_length_cp child of wall_child.
    """
    liquid_content: liquid_content = liquid_content
    """
    liquid_content child of wall_child.
    """
    liquid_content_cp: liquid_content_cp = liquid_content_cp
    """
    liquid_content_cp child of wall_child.
    """
    droplet_diameter: droplet_diameter = droplet_diameter
    """
    droplet_diameter child of wall_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of wall_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of wall_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of wall_child.
    """
    dpm_bc_norm_coeff: dpm_bc_norm_coeff = dpm_bc_norm_coeff
    """
    dpm_bc_norm_coeff child of wall_child.
    """
    dpm_bc_tang_coeff: dpm_bc_tang_coeff = dpm_bc_tang_coeff
    """
    dpm_bc_tang_coeff child of wall_child.
    """
    dpm_bc_frictn_coeff: dpm_bc_frictn_coeff = dpm_bc_frictn_coeff
    """
    dpm_bc_frictn_coeff child of wall_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of wall_child.
    """
    dpm_film_splash_nsamp: dpm_film_splash_nsamp = dpm_film_splash_nsamp
    """
    dpm_film_splash_nsamp child of wall_child.
    """
    dpm_crit_temp_option: dpm_crit_temp_option = dpm_crit_temp_option
    """
    dpm_crit_temp_option child of wall_child.
    """
    dpm_critical_temp_factor: dpm_critical_temp_factor = dpm_critical_temp_factor
    """
    dpm_critical_temp_factor child of wall_child.
    """
    dpm_calibratable_temp: dpm_calibratable_temp = dpm_calibratable_temp
    """
    dpm_calibratable_temp child of wall_child.
    """
    dpm_impingement_splashing_model: dpm_impingement_splashing_model = dpm_impingement_splashing_model
    """
    dpm_impingement_splashing_model child of wall_child.
    """
    dpm_upper_deposition_limit_offset: dpm_upper_deposition_limit_offset = dpm_upper_deposition_limit_offset
    """
    dpm_upper_deposition_limit_offset child of wall_child.
    """
    dpm_deposition_delta_t: dpm_deposition_delta_t = dpm_deposition_delta_t
    """
    dpm_deposition_delta_t child of wall_child.
    """
    dpm_laplace_number_constant: dpm_laplace_number_constant = dpm_laplace_number_constant
    """
    dpm_laplace_number_constant child of wall_child.
    """
    dpm_partial_evaporation_ratio: dpm_partial_evaporation_ratio = dpm_partial_evaporation_ratio
    """
    dpm_partial_evaporation_ratio child of wall_child.
    """
    ra_roughness: ra_roughness = ra_roughness
    """
    ra_roughness child of wall_child.
    """
    rz_roughness: rz_roughness = rz_roughness
    """
    rz_roughness child of wall_child.
    """
    rq_roughness: rq_roughness = rq_roughness
    """
    rq_roughness child of wall_child.
    """
    rsm_roughness: rsm_roughness = rsm_roughness
    """
    rsm_roughness child of wall_child.
    """
    dpm_bc_erosion_generic: dpm_bc_erosion_generic = dpm_bc_erosion_generic
    """
    dpm_bc_erosion_generic child of wall_child.
    """
    dpm_bc_erosion: dpm_bc_erosion = dpm_bc_erosion
    """
    dpm_bc_erosion child of wall_child.
    """
    dpm_bc_erosion_c: dpm_bc_erosion_c = dpm_bc_erosion_c
    """
    dpm_bc_erosion_c child of wall_child.
    """
    dpm_bc_erosion_n: dpm_bc_erosion_n = dpm_bc_erosion_n
    """
    dpm_bc_erosion_n child of wall_child.
    """
    dpm_bc_erosion_finnie: dpm_bc_erosion_finnie = dpm_bc_erosion_finnie
    """
    dpm_bc_erosion_finnie child of wall_child.
    """
    dpm_bc_erosion_finnie_k: dpm_bc_erosion_finnie_k = dpm_bc_erosion_finnie_k
    """
    dpm_bc_erosion_finnie_k child of wall_child.
    """
    dpm_bc_erosion_finnie_vel_exp: dpm_bc_erosion_finnie_vel_exp = dpm_bc_erosion_finnie_vel_exp
    """
    dpm_bc_erosion_finnie_vel_exp child of wall_child.
    """
    dpm_bc_erosion_finnie_max_erosion_angle: dpm_bc_erosion_finnie_max_erosion_angle = dpm_bc_erosion_finnie_max_erosion_angle
    """
    dpm_bc_erosion_finnie_max_erosion_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury: dpm_bc_erosion_mclaury = dpm_bc_erosion_mclaury
    """
    dpm_bc_erosion_mclaury child of wall_child.
    """
    dpm_bc_erosion_mclaury_a: dpm_bc_erosion_mclaury_a = dpm_bc_erosion_mclaury_a
    """
    dpm_bc_erosion_mclaury_a child of wall_child.
    """
    dpm_bc_erosion_mclaury_vel_exp: dpm_bc_erosion_mclaury_vel_exp = dpm_bc_erosion_mclaury_vel_exp
    """
    dpm_bc_erosion_mclaury_vel_exp child of wall_child.
    """
    dpm_bc_erosion_mclaury_transition_angle: dpm_bc_erosion_mclaury_transition_angle = dpm_bc_erosion_mclaury_transition_angle
    """
    dpm_bc_erosion_mclaury_transition_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury_b: dpm_bc_erosion_mclaury_b = dpm_bc_erosion_mclaury_b
    """
    dpm_bc_erosion_mclaury_b child of wall_child.
    """
    dpm_bc_erosion_mclaury_c: dpm_bc_erosion_mclaury_c = dpm_bc_erosion_mclaury_c
    """
    dpm_bc_erosion_mclaury_c child of wall_child.
    """
    dpm_bc_erosion_mclaury_w: dpm_bc_erosion_mclaury_w = dpm_bc_erosion_mclaury_w
    """
    dpm_bc_erosion_mclaury_w child of wall_child.
    """
    dpm_bc_erosion_mclaury_x: dpm_bc_erosion_mclaury_x = dpm_bc_erosion_mclaury_x
    """
    dpm_bc_erosion_mclaury_x child of wall_child.
    """
    dpm_bc_erosion_mclaury_y: dpm_bc_erosion_mclaury_y = dpm_bc_erosion_mclaury_y
    """
    dpm_bc_erosion_mclaury_y child of wall_child.
    """
    dpm_bc_erosion_oka: dpm_bc_erosion_oka = dpm_bc_erosion_oka
    """
    dpm_bc_erosion_oka child of wall_child.
    """
    dpm_bc_erosion_oka_e90: dpm_bc_erosion_oka_e90 = dpm_bc_erosion_oka_e90
    """
    dpm_bc_erosion_oka_e90 child of wall_child.
    """
    dpm_bc_erosion_oka_hv: dpm_bc_erosion_oka_hv = dpm_bc_erosion_oka_hv
    """
    dpm_bc_erosion_oka_hv child of wall_child.
    """
    dpm_bc_erosion_oka_n1: dpm_bc_erosion_oka_n1 = dpm_bc_erosion_oka_n1
    """
    dpm_bc_erosion_oka_n1 child of wall_child.
    """
    dpm_bc_erosion_oka_n2: dpm_bc_erosion_oka_n2 = dpm_bc_erosion_oka_n2
    """
    dpm_bc_erosion_oka_n2 child of wall_child.
    """
    dpm_bc_erosion_oka_k2: dpm_bc_erosion_oka_k2 = dpm_bc_erosion_oka_k2
    """
    dpm_bc_erosion_oka_k2 child of wall_child.
    """
    dpm_bc_erosion_oka_k3: dpm_bc_erosion_oka_k3 = dpm_bc_erosion_oka_k3
    """
    dpm_bc_erosion_oka_k3 child of wall_child.
    """
    dpm_bc_erosion_oka_dref: dpm_bc_erosion_oka_dref = dpm_bc_erosion_oka_dref
    """
    dpm_bc_erosion_oka_dref child of wall_child.
    """
    dpm_bc_erosion_oka_vref: dpm_bc_erosion_oka_vref = dpm_bc_erosion_oka_vref
    """
    dpm_bc_erosion_oka_vref child of wall_child.
    """
    dpm_bc_erosion_dnv: dpm_bc_erosion_dnv = dpm_bc_erosion_dnv
    """
    dpm_bc_erosion_dnv child of wall_child.
    """
    dpm_bc_erosion_dnv_k: dpm_bc_erosion_dnv_k = dpm_bc_erosion_dnv_k
    """
    dpm_bc_erosion_dnv_k child of wall_child.
    """
    dpm_bc_erosion_dnv_n: dpm_bc_erosion_dnv_n = dpm_bc_erosion_dnv_n
    """
    dpm_bc_erosion_dnv_n child of wall_child.
    """
    dpm_bc_erosion_dnv_ductile: dpm_bc_erosion_dnv_ductile = dpm_bc_erosion_dnv_ductile
    """
    dpm_bc_erosion_dnv_ductile child of wall_child.
    """
    dpm_bc_erosion_shear: dpm_bc_erosion_shear = dpm_bc_erosion_shear
    """
    dpm_bc_erosion_shear child of wall_child.
    """
    dpm_bc_erosion_shear_v: dpm_bc_erosion_shear_v = dpm_bc_erosion_shear_v
    """
    dpm_bc_erosion_shear_v child of wall_child.
    """
    dpm_bc_erosion_shear_c: dpm_bc_erosion_shear_c = dpm_bc_erosion_shear_c
    """
    dpm_bc_erosion_shear_c child of wall_child.
    """
    dpm_bc_erosion_shear_packing_limit: dpm_bc_erosion_shear_packing_limit = dpm_bc_erosion_shear_packing_limit
    """
    dpm_bc_erosion_shear_packing_limit child of wall_child.
    """
    dpm_bc_erosion_shielding: dpm_bc_erosion_shielding = dpm_bc_erosion_shielding
    """
    dpm_bc_erosion_shielding child of wall_child.
    """
    dpm_wall_heat_exchange: dpm_wall_heat_exchange = dpm_wall_heat_exchange
    """
    dpm_wall_heat_exchange child of wall_child.
    """
    dpm_film_condensation: dpm_film_condensation = dpm_film_condensation
    """
    dpm_film_condensation child of wall_child.
    """
    dpm_film_bl_model: dpm_film_bl_model = dpm_film_bl_model
    """
    dpm_film_bl_model child of wall_child.
    """
    dpm_particle_stripping: dpm_particle_stripping = dpm_particle_stripping
    """
    dpm_particle_stripping child of wall_child.
    """
    dpm_critical_shear_stress: dpm_critical_shear_stress = dpm_critical_shear_stress
    """
    dpm_critical_shear_stress child of wall_child.
    """
    dpm_film_separation_model: dpm_film_separation_model = dpm_film_separation_model
    """
    dpm_film_separation_model child of wall_child.
    """
    dpm_critical_we_number: dpm_critical_we_number = dpm_critical_we_number
    """
    dpm_critical_we_number child of wall_child.
    """
    dpm_film_separation_angle: dpm_film_separation_angle = dpm_film_separation_angle
    """
    dpm_film_separation_angle child of wall_child.
    """
    dpm_allow_lwf_to_vof: dpm_allow_lwf_to_vof = dpm_allow_lwf_to_vof
    """
    dpm_allow_lwf_to_vof child of wall_child.
    """
    dpm_allow_vof_to_lwf: dpm_allow_vof_to_lwf = dpm_allow_vof_to_lwf
    """
    dpm_allow_vof_to_lwf child of wall_child.
    """
    dpm_initialize_lwf: dpm_initialize_lwf = dpm_initialize_lwf
    """
    dpm_initialize_lwf child of wall_child.
    """
    dpm_initial_height: dpm_initial_height = dpm_initial_height
    """
    dpm_initial_height child of wall_child.
    """
    film_velocity: film_velocity = film_velocity
    """
    film_velocity child of wall_child.
    """
    dpm_initial_temperature: dpm_initial_temperature = dpm_initial_temperature
    """
    dpm_initial_temperature child of wall_child.
    """
    dpm_initial_injection: dpm_initial_injection = dpm_initial_injection
    """
    dpm_initial_injection child of wall_child.
    """
    film_parcel_surface_area_density: film_parcel_surface_area_density = film_parcel_surface_area_density
    """
    film_parcel_surface_area_density child of wall_child.
    """
    minimum_number_of_parcels_per_face: minimum_number_of_parcels_per_face = minimum_number_of_parcels_per_face
    """
    minimum_number_of_parcels_per_face child of wall_child.
    """
    band_in_emiss: band_in_emiss = band_in_emiss
    """
    band_in_emiss child of wall_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of wall_child.
    """
    mc_bsource_p: mc_bsource_p = mc_bsource_p
    """
    mc_bsource_p child of wall_child.
    """
    mc_poldfun_p: mc_poldfun_p = mc_poldfun_p
    """
    mc_poldfun_p child of wall_child.
    """
    polar_func_type: polar_func_type = polar_func_type
    """
    polar_func_type child of wall_child.
    """
    mc_polar_expr: mc_polar_expr = mc_polar_expr
    """
    mc_polar_expr child of wall_child.
    """
    polar_pair_list: polar_pair_list = polar_pair_list
    """
    polar_pair_list child of wall_child.
    """
    pold_pair_list_rad: pold_pair_list_rad = pold_pair_list_rad
    """
    pold_pair_list_rad child of wall_child.
    """
    radiation_direction: radiation_direction = radiation_direction
    """
    radiation_direction child of wall_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of wall_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of wall_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of wall_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of wall_child.
    """
    band_diffuse_frac: band_diffuse_frac = band_diffuse_frac
    """
    band_diffuse_frac child of wall_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of wall_child.
    """
    critical_zone: critical_zone = critical_zone
    """
    critical_zone child of wall_child.
    """
    fpsc: fpsc = fpsc
    """
    fpsc child of wall_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of wall_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of wall_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of wall_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of wall_child.
    """
    v_transmissivity: v_transmissivity = v_transmissivity
    """
    v_transmissivity child of wall_child.
    """
    ir_transmissivity: ir_transmissivity = ir_transmissivity
    """
    ir_transmissivity child of wall_child.
    """
    v_opq_absorbtivity: v_opq_absorbtivity = v_opq_absorbtivity
    """
    v_opq_absorbtivity child of wall_child.
    """
    ir_opq_absorbtivity: ir_opq_absorbtivity = ir_opq_absorbtivity
    """
    ir_opq_absorbtivity child of wall_child.
    """
    v_st_absorbtivity: v_st_absorbtivity = v_st_absorbtivity
    """
    v_st_absorbtivity child of wall_child.
    """
    ir_st_absorbtivity: ir_st_absorbtivity = ir_st_absorbtivity
    """
    ir_st_absorbtivity child of wall_child.
    """
    d_st_absorbtivity: d_st_absorbtivity = d_st_absorbtivity
    """
    d_st_absorbtivity child of wall_child.
    """
    d_transmissivity: d_transmissivity = d_transmissivity
    """
    d_transmissivity child of wall_child.
    """
    fsi_interface: fsi_interface = fsi_interface
    """
    fsi_interface child of wall_child.
    """
    react: react = react
    """
    react child of wall_child.
    """
    partially_catalytic: partially_catalytic = partially_catalytic
    """
    partially_catalytic child of wall_child.
    """
    partially_catalytic_material: partially_catalytic_material = partially_catalytic_material
    """
    partially_catalytic_material child of wall_child.
    """
    partially_catalytic_recombination_coefficient_o: partially_catalytic_recombination_coefficient_o = partially_catalytic_recombination_coefficient_o
    """
    partially_catalytic_recombination_coefficient_o child of wall_child.
    """
    partially_catalytic_recombination_coefficient_n: partially_catalytic_recombination_coefficient_n = partially_catalytic_recombination_coefficient_n
    """
    partially_catalytic_recombination_coefficient_n child of wall_child.
    """
    partially_catalytic_recombination_model: partially_catalytic_recombination_model = partially_catalytic_recombination_model
    """
    partially_catalytic_recombination_model child of wall_child.
    """
    species_spec: species_spec = species_spec
    """
    species_spec child of wall_child.
    """
    mf: mf = mf
    """
    mf child of wall_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of wall_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of wall_child.
    """
    elec_potential_jump: elec_potential_jump = elec_potential_jump
    """
    elec_potential_jump child of wall_child.
    """
    elec_potential_resistance: elec_potential_resistance = elec_potential_resistance
    """
    elec_potential_resistance child of wall_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of wall_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of wall_child.
    """
    echem_reaction: echem_reaction = echem_reaction
    """
    echem_reaction child of wall_child.
    """
    elec_potential_mechs: elec_potential_mechs = elec_potential_mechs
    """
    elec_potential_mechs child of wall_child.
    """
    faradaic_heat: faradaic_heat = faradaic_heat
    """
    faradaic_heat child of wall_child.
    """
    li_ion_type: li_ion_type = li_ion_type
    """
    li_ion_type child of wall_child.
    """
    li_ion_value: li_ion_value = li_ion_value
    """
    li_ion_value child of wall_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of wall_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of wall_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of wall_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of wall_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of wall_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of wall_child.
    """
    per_dispx: per_dispx = per_dispx
    """
    per_dispx child of wall_child.
    """
    per_dispy: per_dispy = per_dispy
    """
    per_dispy child of wall_child.
    """
    per_dispz: per_dispz = per_dispz
    """
    per_dispz child of wall_child.
    """
    per_imagx: per_imagx = per_imagx
    """
    per_imagx child of wall_child.
    """
    per_imagy: per_imagy = per_imagy
    """
    per_imagy child of wall_child.
    """
    per_imagz: per_imagz = per_imagz
    """
    per_imagz child of wall_child.
    """
    freq: freq = freq
    """
    freq child of wall_child.
    """
    amp: amp = amp
    """
    amp child of wall_child.
    """
    nodal_diam: nodal_diam = nodal_diam
    """
    nodal_diam child of wall_child.
    """
    pass_number: pass_number = pass_number
    """
    pass_number child of wall_child.
    """
    fwd: fwd = fwd
    """
    fwd child of wall_child.
    """
    aero: aero = aero
    """
    aero child of wall_child.
    """
    cmplx: cmplx = cmplx
    """
    cmplx child of wall_child.
    """
    norm: norm = norm
    """
    norm child of wall_child.
    """
    method: method = method
    """
    method child of wall_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of wall_child.
    """
    uds: uds = uds
    """
    uds child of wall_child.
    """
    gtemp_bc: gtemp_bc = gtemp_bc
    """
    gtemp_bc child of wall_child.
    """
    g_temperature: g_temperature = g_temperature
    """
    g_temperature child of wall_child.
    """
    g_qflux: g_qflux = g_qflux
    """
    g_qflux child of wall_child.
    """
    wall_restitution_coeff: wall_restitution_coeff = wall_restitution_coeff
    """
    wall_restitution_coeff child of wall_child.
    """
    omega: omega = omega
    """
    omega child of wall_child.
    """
    rotation_axis_origin: rotation_axis_origin = rotation_axis_origin
    """
    rotation_axis_origin child of wall_child.
    """
    rotation_axis_direction: rotation_axis_direction = rotation_axis_direction
    """
    rotation_axis_direction child of wall_child.
    """
    adhesion_angle: adhesion_angle = adhesion_angle
    """
    adhesion_angle child of wall_child.
    """
    specified_shear: specified_shear = specified_shear
    """
    specified_shear child of wall_child.
    """
    shear_stress: shear_stress = shear_stress
    """
    shear_stress child of wall_child.
    """
    fslip: fslip = fslip
    """
    fslip child of wall_child.
    """
    eslip: eslip = eslip
    """
    eslip child of wall_child.
    """
    surf_tens_grad: surf_tens_grad = surf_tens_grad
    """
    surf_tens_grad child of wall_child.
    """
    contact_resistance: contact_resistance = contact_resistance
    """
    contact_resistance child of wall_child.
    """
    reaction_mechs: reaction_mechs = reaction_mechs
    """
    reaction_mechs child of wall_child.
    """
    surf_washcoat_factor: surf_washcoat_factor = surf_washcoat_factor
    """
    surf_washcoat_factor child of wall_child.
    """
    initial_deposition_height: initial_deposition_height = initial_deposition_height
    """
    initial_deposition_height child of wall_child.
    """
    solid_species_density: solid_species_density = solid_species_density
    """
    solid_species_density child of wall_child.
    """
    ablation_select_model: ablation_select_model = ablation_select_model
    """
    ablation_select_model child of wall_child.
    """
    ablation_vielle_a: ablation_vielle_a = ablation_vielle_a
    """
    ablation_vielle_a child of wall_child.
    """
    ablation_vielle_n: ablation_vielle_n = ablation_vielle_n
    """
    ablation_vielle_n child of wall_child.
    """
    ablation_flux: ablation_flux = ablation_flux
    """
    ablation_flux child of wall_child.
    """
    ablation_surfacerxn_density: ablation_surfacerxn_density = ablation_surfacerxn_density
    """
    ablation_surfacerxn_density child of wall_child.
    """
    ablation_species_mf: ablation_species_mf = ablation_species_mf
    """
    ablation_species_mf child of wall_child.
    """
    specular_coeff: specular_coeff = specular_coeff
    """
    specular_coeff child of wall_child.
    """
    mom_accom_coef: mom_accom_coef = mom_accom_coef
    """
    mom_accom_coef child of wall_child.
    """
    therm_accom_coef: therm_accom_coef = therm_accom_coef
    """
    therm_accom_coef child of wall_child.
    """
    eve_accom_coef: eve_accom_coef = eve_accom_coef
    """
    eve_accom_coef child of wall_child.
    """
    film_wall: film_wall = film_wall
    """
    film_wall child of wall_child.
    """
    film_wall_bc: film_wall_bc = film_wall_bc
    """
    film_wall_bc child of wall_child.
    """
    film_height: film_height = film_height
    """
    film_height child of wall_child.
    """
    flux_momentum: flux_momentum = flux_momentum
    """
    flux_momentum child of wall_child.
    """
    film_relative_vel: film_relative_vel = film_relative_vel
    """
    film_relative_vel child of wall_child.
    """
    film_bc_imp_press: film_bc_imp_press = film_bc_imp_press
    """
    film_bc_imp_press child of wall_child.
    """
    film_temperature: film_temperature = film_temperature
    """
    film_temperature child of wall_child.
    """
    film_scalar: film_scalar = film_scalar
    """
    film_scalar child of wall_child.
    """
    film_source: film_source = film_source
    """
    film_source child of wall_child.
    """
    film_h_src: film_h_src = film_h_src
    """
    film_h_src child of wall_child.
    """
    momentum_source: momentum_source = momentum_source
    """
    momentum_source child of wall_child.
    """
    film_t_src: film_t_src = film_t_src
    """
    film_t_src child of wall_child.
    """
    film_s_src: film_s_src = film_s_src
    """
    film_s_src child of wall_child.
    """
    film_phase_change: film_phase_change = film_phase_change
    """
    film_phase_change child of wall_child.
    """
    film_phase_change_model: film_phase_change_model = film_phase_change_model
    """
    film_phase_change_model child of wall_child.
    """
    film_cond_const: film_cond_const = film_cond_const
    """
    film_cond_const child of wall_child.
    """
    film_vapo_const: film_vapo_const = film_vapo_const
    """
    film_vapo_const child of wall_child.
    """
    film_cond_rate: film_cond_rate = film_cond_rate
    """
    film_cond_rate child of wall_child.
    """
    film_vapo_rate: film_vapo_rate = film_vapo_rate
    """
    film_vapo_rate child of wall_child.
    """
    film_momentum_coupling: film_momentum_coupling = film_momentum_coupling
    """
    film_momentum_coupling child of wall_child.
    """
    film_splash_wall: film_splash_wall = film_splash_wall
    """
    film_splash_wall child of wall_child.
    """
    film_boundary_separation: film_boundary_separation = film_boundary_separation
    """
    film_boundary_separation child of wall_child.
    """
    film_impinge_model: film_impinge_model = film_impinge_model
    """
    film_impinge_model child of wall_child.
    """
    film_splash_nparc: film_splash_nparc = film_splash_nparc
    """
    film_splash_nparc child of wall_child.
    """
    film_crit_temp_factor: film_crit_temp_factor = film_crit_temp_factor
    """
    film_crit_temp_factor child of wall_child.
    """
    film_roughness_ra: film_roughness_ra = film_roughness_ra
    """
    film_roughness_ra child of wall_child.
    """
    film_roughness_rz: film_roughness_rz = film_roughness_rz
    """
    film_roughness_rz child of wall_child.
    """
    film_upper_deposition_limit_offset: film_upper_deposition_limit_offset = film_upper_deposition_limit_offset
    """
    film_upper_deposition_limit_offset child of wall_child.
    """
    film_deposition_delta_t: film_deposition_delta_t = film_deposition_delta_t
    """
    film_deposition_delta_t child of wall_child.
    """
    film_laplace_number_constant: film_laplace_number_constant = film_laplace_number_constant
    """
    film_laplace_number_constant child of wall_child.
    """
    film_partial_evap_ratio: film_partial_evap_ratio = film_partial_evap_ratio
    """
    film_partial_evap_ratio child of wall_child.
    """
    film_contact_angle: film_contact_angle = film_contact_angle
    """
    film_contact_angle child of wall_child.
    """
    film_contact_angle_mean: film_contact_angle_mean = film_contact_angle_mean
    """
    film_contact_angle_mean child of wall_child.
    """
    film_contact_angle_rstd: film_contact_angle_rstd = film_contact_angle_rstd
    """
    film_contact_angle_rstd child of wall_child.
    """
    film_contact_angle_beta: film_contact_angle_beta = film_contact_angle_beta
    """
    film_contact_angle_beta child of wall_child.
    """
    film_vof_coupling_high: film_vof_coupling_high = film_vof_coupling_high
    """
    film_vof_coupling_high child of wall_child.
    """
    film_vof_trans_high: film_vof_trans_high = film_vof_trans_high
    """
    film_vof_trans_high child of wall_child.
    """
    film_vof_trans_high_relax: film_vof_trans_high_relax = film_vof_trans_high_relax
    """
    film_vof_trans_high_relax child of wall_child.
    """
    film_vof_coupling_low: film_vof_coupling_low = film_vof_coupling_low
    """
    film_vof_coupling_low child of wall_child.
    """
    film_vof_trans_low: film_vof_trans_low = film_vof_trans_low
    """
    film_vof_trans_low child of wall_child.
    """
    film_vof_trans_low_relax: film_vof_trans_low_relax = film_vof_trans_low_relax
    """
    film_vof_trans_low_relax child of wall_child.
    """
    caf: caf = caf
    """
    caf child of wall_child.
    """
    thermal_stabilization: thermal_stabilization = thermal_stabilization
    """
    thermal_stabilization child of wall_child.
    """
    scale_factor: scale_factor = scale_factor
    """
    scale_factor child of wall_child.
    """
    stab_method: stab_method = stab_method
    """
    stab_method child of wall_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype = fensapice_flow_bc_subtype
    """
    fensapice_flow_bc_subtype child of wall_child.
    """
    fensapice_ice_icing_mode: fensapice_ice_icing_mode = fensapice_ice_icing_mode
    """
    fensapice_ice_icing_mode child of wall_child.
    """
    fensapice_ice_hflux: fensapice_ice_hflux = fensapice_ice_hflux
    """
    fensapice_ice_hflux child of wall_child.
    """
    fensapice_ice_hflux_1: fensapice_ice_hflux_1 = fensapice_ice_hflux_1
    """
    fensapice_ice_hflux_1 child of wall_child.
    """
    fensapice_drop_vwet: fensapice_drop_vwet = fensapice_drop_vwet
    """
    fensapice_drop_vwet child of wall_child.
    """
