#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .chemical_formula import chemical_formula
from .density_3 import density
from .thermal_conductivity_3 import thermal_conductivity
from .vaporization_model import vaporization_model
from .thermolysis_model import thermolysis_model
from .latent_heat_1 import latent_heat
from .volatile_fraction import volatile_fraction
from .heat_of_pyrolysis import heat_of_pyrolysis
from .specific_heat_3 import specific_heat
from .binary_diffusivity_1 import binary_diffusivity
from .diffusivity_reference_pressure import diffusivity_reference_pressure
from .averaging_coefficient_t import averaging_coefficient_t
from .averaging_coefficient_y import averaging_coefficient_y
from .vapor_pressure import vapor_pressure
from .molecular_weight_1 import molecular_weight
from .vaporization_temperature import vaporization_temperature
from .boiling_point import boiling_point
from .thermophoretic_co import thermophoretic_co
from .scattering_factor_1 import scattering_factor
from .emissivity_1 import emissivity
from .viscosity_2 import viscosity
from .dpm_surften_1 import dpm_surften
from .electric_conductivity_1 import electric_conductivity
from .dual_electric_conductivity_1 import dual_electric_conductivity
from .magnetic_permeability import magnetic_permeability
from .charge_density import charge_density
from .formation_entropy import formation_entropy
from .formation_enthalpy import formation_enthalpy
from .reference_temperature_1 import reference_temperature
class droplet_particle_child(Group):
    """
    'child_object_type' of droplet_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['chemical_formula', 'density', 'thermal_conductivity',
         'vaporization_model', 'thermolysis_model', 'latent_heat',
         'volatile_fraction', 'heat_of_pyrolysis', 'specific_heat',
         'binary_diffusivity', 'diffusivity_reference_pressure',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vapor_pressure', 'molecular_weight', 'vaporization_temperature',
         'boiling_point', 'thermophoretic_co', 'scattering_factor',
         'emissivity', 'viscosity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'magnetic_permeability',
         'charge_density', 'formation_entropy', 'formation_enthalpy',
         'reference_temperature']

    chemical_formula: chemical_formula = chemical_formula
    """
    chemical_formula child of droplet_particle_child.
    """
    density: density = density
    """
    density child of droplet_particle_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of droplet_particle_child.
    """
    vaporization_model: vaporization_model = vaporization_model
    """
    vaporization_model child of droplet_particle_child.
    """
    thermolysis_model: thermolysis_model = thermolysis_model
    """
    thermolysis_model child of droplet_particle_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of droplet_particle_child.
    """
    volatile_fraction: volatile_fraction = volatile_fraction
    """
    volatile_fraction child of droplet_particle_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis = heat_of_pyrolysis
    """
    heat_of_pyrolysis child of droplet_particle_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of droplet_particle_child.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of droplet_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure = diffusivity_reference_pressure
    """
    diffusivity_reference_pressure child of droplet_particle_child.
    """
    averaging_coefficient_t: averaging_coefficient_t = averaging_coefficient_t
    """
    averaging_coefficient_t child of droplet_particle_child.
    """
    averaging_coefficient_y: averaging_coefficient_y = averaging_coefficient_y
    """
    averaging_coefficient_y child of droplet_particle_child.
    """
    vapor_pressure: vapor_pressure = vapor_pressure
    """
    vapor_pressure child of droplet_particle_child.
    """
    molecular_weight: molecular_weight = molecular_weight
    """
    molecular_weight child of droplet_particle_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of droplet_particle_child.
    """
    boiling_point: boiling_point = boiling_point
    """
    boiling_point child of droplet_particle_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of droplet_particle_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of droplet_particle_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of droplet_particle_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of droplet_particle_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of droplet_particle_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of droplet_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of droplet_particle_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of droplet_particle_child.
    """
    charge_density: charge_density = charge_density
    """
    charge_density child of droplet_particle_child.
    """
    formation_entropy: formation_entropy = formation_entropy
    """
    formation_entropy child of droplet_particle_child.
    """
    formation_enthalpy: formation_enthalpy = formation_enthalpy
    """
    formation_enthalpy child of droplet_particle_child.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of droplet_particle_child.
    """
