#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class set_offset_above_film_boiling_temperature(Real):
    """
    Set the temperature difference above the film boiling point.
    """

    fluent_name = "set-offset-above-film-boiling-temperature"

