#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class blade_pitch_cyclic_cos(Real):
    """
    Set magnitude of cos component of blade's cyclic pitch angle:.
    """

    fluent_name = "blade-pitch-cyclic-cos"

