#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class explicit_relaxation_factor(Real):
    """
    Specify explicit relaxation factor to be applied to
    the solution correction when updating solution in the timestep iterations.
    """

    fluent_name = "explicit-relaxation-factor"

