#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class old_variant_of_pesto_for_cases_using_structured_mesh(Boolean):
    """
    'old_variant_of_pesto_for_cases_using_structured_mesh' child.
    """

    fluent_name = "old-variant-of-pesto-for-cases-using-structured-mesh"

