#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class tip_loss_limit(Real):
    """
    Set Tip Loss Limit (%R) if using Quadratic tip loss model:.
    """

    fluent_name = "tip-loss-limit"

