#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .list_simulation_reports import list_simulation_reports
from .generate_simulation_report import generate_simulation_report
from .view_simulation_report import view_simulation_report
from .export_simulation_report_as_pdf import export_simulation_report_as_pdf
from .export_simulation_report_as_html import export_simulation_report_as_html
from .export_simulation_report_as_pptx import export_simulation_report_as_pptx
from .write_simulation_report_names_to_file import write_simulation_report_names_to_file
from .rename_simulation_report import rename_simulation_report
from .duplicate_simulation_report import duplicate_simulation_report
from .reset_report_to_defaults import reset_report_to_defaults
from .delete_simulation_report import delete_simulation_report
from .write_simulation_report_template_file import write_simulation_report_template_file
from .read_simulation_report_template_file import read_simulation_report_template_file
class simulation_reports(Group):
    """
    'simulation_reports' child.
    """

    fluent_name = "simulation-reports"

    command_names = \
        ['list_simulation_reports', 'generate_simulation_report',
         'view_simulation_report', 'export_simulation_report_as_pdf',
         'export_simulation_report_as_html',
         'export_simulation_report_as_pptx',
         'write_simulation_report_names_to_file', 'rename_simulation_report',
         'duplicate_simulation_report', 'reset_report_to_defaults',
         'delete_simulation_report', 'write_simulation_report_template_file',
         'read_simulation_report_template_file']

    list_simulation_reports: list_simulation_reports = list_simulation_reports
    """
    list_simulation_reports command of simulation_reports.
    """
    generate_simulation_report: generate_simulation_report = generate_simulation_report
    """
    generate_simulation_report command of simulation_reports.
    """
    view_simulation_report: view_simulation_report = view_simulation_report
    """
    view_simulation_report command of simulation_reports.
    """
    export_simulation_report_as_pdf: export_simulation_report_as_pdf = export_simulation_report_as_pdf
    """
    export_simulation_report_as_pdf command of simulation_reports.
    """
    export_simulation_report_as_html: export_simulation_report_as_html = export_simulation_report_as_html
    """
    export_simulation_report_as_html command of simulation_reports.
    """
    export_simulation_report_as_pptx: export_simulation_report_as_pptx = export_simulation_report_as_pptx
    """
    export_simulation_report_as_pptx command of simulation_reports.
    """
    write_simulation_report_names_to_file: write_simulation_report_names_to_file = write_simulation_report_names_to_file
    """
    write_simulation_report_names_to_file command of simulation_reports.
    """
    rename_simulation_report: rename_simulation_report = rename_simulation_report
    """
    rename_simulation_report command of simulation_reports.
    """
    duplicate_simulation_report: duplicate_simulation_report = duplicate_simulation_report
    """
    duplicate_simulation_report command of simulation_reports.
    """
    reset_report_to_defaults: reset_report_to_defaults = reset_report_to_defaults
    """
    reset_report_to_defaults command of simulation_reports.
    """
    delete_simulation_report: delete_simulation_report = delete_simulation_report
    """
    delete_simulation_report command of simulation_reports.
    """
    write_simulation_report_template_file: write_simulation_report_template_file = write_simulation_report_template_file
    """
    write_simulation_report_template_file command of simulation_reports.
    """
    read_simulation_report_template_file: read_simulation_report_template_file = read_simulation_report_template_file
    """
    read_simulation_report_template_file command of simulation_reports.
    """
