#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .new import new
from .open import open
from .save import save
from .save_as import save_as
from .save_as_copy import save_as_copy
from .archive import archive
class parametric_project(Group):
    """
    'parametric_project' child.
    """

    fluent_name = "parametric-project"

    command_names = \
        ['new', 'open', 'save', 'save_as', 'save_as_copy', 'archive']

    new: new = new
    """
    new command of parametric_project.
    """
    open: open = open
    """
    open command of parametric_project.
    """
    save: save = save
    """
    save command of parametric_project.
    """
    save_as: save_as = save_as
    """
    save_as command of parametric_project.
    """
    save_as_copy: save_as_copy = save_as_copy
    """
    save_as_copy command of parametric_project.
    """
    archive: archive = archive
    """
    archive command of parametric_project.
    """
