#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class migrate_and_reorder(Boolean):
    """
    Perform migration and reordering at the end of the polyhedra conversion.
    """

    fluent_name = "migrate-and-reorder?"

